@@ -25,7 +25,7 @@
  * list of people on the gedit Team.  
  * See the ChangeLog files for a list of changes. 
  *
- * $Id: gedit-tab.h 5667 2007-06-30 09:51:18Z pborelli $
+ * $Id$
  */
 
 #ifndef __GEDIT_TAB_H__
@@ -146,16 +146,10 @@ void		 _gedit_tab_save_as		(GeditTab            *tab,
 						 const gchar         *uri,
 						 const GeditEncoding *encoding);
 
-/* print_job is a gpointer instead of GeditPrintJob because gedit-print is
- * is not public so it cannot be included in this header */
-void		 _gedit_tab_print		(GeditTab            *tab,
-						 gpointer             print_job,
-						 GtkTextIter         *start, 
-			  			 GtkTextIter         *end);
-void		 _gedit_tab_print_preview	(GeditTab            *tab,
-						 gpointer             print_job,
-						 GtkTextIter         *start, 
-			  			 GtkTextIter         *end);
+void		 _gedit_tab_page_setup		(GeditTab            *tab);
+void		 _gedit_tab_print		(GeditTab            *tab);
+void		 _gedit_tab_print_preview	(GeditTab            *tab);
+
 void		 _gedit_tab_mark_for_closing	(GeditTab	     *tab);
 
 gboolean	 _gedit_tab_can_close		(GeditTab	     *tab);
