@@ -23,7 +23,6 @@
 #define __GEDIT_FILE_BROWSER_WIDGET_H__
 
 #include <gtk/gtk.h>
-#include <libgnomevfs/gnome-vfs.h>
 #include "gedit-file-browser-store.h"
 #include "gedit-file-bookmarks-store.h"
 #include "gedit-file-browser-view.h"
@@ -66,18 +65,19 @@ struct _GeditFileBrowserWidgetClass
 		                      gchar const *message);
 	gboolean (*confirm_delete)   (GeditFileBrowserWidget * widget,
 	                              GeditFileBrowserStore * model,
-	                              GtkTreeIter * iter);
+	                              GList *list);
 	gboolean (*confirm_no_trash) (GeditFileBrowserWidget * widget,
-                                      GeditFileBrowserStore * model,
-	                              GtkTreeIter * iter);
+	                              GList *list);
 };
 
 GType gedit_file_browser_widget_get_type            (void) G_GNUC_CONST;
 GType gedit_file_browser_widget_register_type       (GTypeModule * module);
 
-GtkWidget *gedit_file_browser_widget_new            (void);
+GtkWidget *gedit_file_browser_widget_new            (const gchar *data_dir);
 
 void gedit_file_browser_widget_show_bookmarks       (GeditFileBrowserWidget * obj);
+void gedit_file_browser_widget_show_files           (GeditFileBrowserWidget * obj);
+
 void gedit_file_browser_widget_set_root             (GeditFileBrowserWidget * obj,
                                                      gchar const *root,
                                                      gboolean virtual_root);
@@ -89,6 +89,9 @@ gedit_file_browser_widget_set_root_and_virtual_root (GeditFileBrowserWidget * ob
 gboolean
 gedit_file_browser_widget_get_selected_directory    (GeditFileBrowserWidget * obj, 
                                                      GtkTreeIter * iter);
+guint
+gedit_file_browser_widget_get_num_selected_files_or_directories (GeditFileBrowserWidget *obj);
+
 GeditFileBrowserStore * 
 gedit_file_browser_widget_get_browser_store         (GeditFileBrowserWidget * obj);
 GeditFileBookmarksStore * 
@@ -103,13 +106,18 @@ gedit_file_browser_widget_get_ui_manager            (GeditFileBrowserWidget * ob
 
 gulong gedit_file_browser_widget_add_filter         (GeditFileBrowserWidget * obj,
                                                      GeditFileBrowserWidgetFilterFunc func, 
-                                                     gpointer user_data);
+                                                     gpointer user_data,
+                                                     GDestroyNotify notify);
 void gedit_file_browser_widget_remove_filter        (GeditFileBrowserWidget * obj,
                                                      gulong id);
 void gedit_file_browser_widget_set_filter_pattern   (GeditFileBrowserWidget * obj,
                                                      gchar const *pattern);
 
+void gedit_file_browser_widget_refresh		    (GeditFileBrowserWidget * obj);
+void gedit_file_browser_widget_history_back	    (GeditFileBrowserWidget * obj);
+void gedit_file_browser_widget_history_forward	    (GeditFileBrowserWidget * obj);
+
 G_END_DECLS
-#endif				/* __GEDIT_FILE_BROWSER_WIDGET_H__ */
+#endif /* __GEDIT_FILE_BROWSER_WIDGET_H__ */
 
 // ex:ts=8:noet:
